var indexSectionsWithContent =
{
  0: "_abcdefghijklmnopqrstuvwxy~",
  1: "_abcdefghilmnoprstuvw",
  2: "cors",
  3: "abcdefgilmnpqrstuw",
  4: "abcdefghijlmnopqrstuvwy~",
  5: "_abcdefghilmnoprsuvxy",
  6: "cekmoprstu",
  7: "_iortu",
  8: "bdefilorstuv",
  9: "cdioptv",
  10: "cmoprsu",
  11: "afv",
  12: "bdst"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "files",
  4: "functions",
  5: "variables",
  6: "typedefs",
  7: "enums",
  8: "enumvalues",
  9: "related",
  10: "defines",
  11: "groups",
  12: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Files",
  4: "Functions",
  5: "Variables",
  6: "Typedefs",
  7: "Enumerations",
  8: "Enumerator",
  9: "Friends",
  10: "Macros",
  11: "Modules",
  12: "Pages"
};

